Enumeration
AdwEasing
Description [src]
Describes the available easing functions for use with
AdwTimedAnimation.
New values may be added to this enumeration over time.
Members
| Name | Description |
|---|---|
ADW_LINEAR |
Linear tweening. |
ADW_EASE_IN_QUAD |
Quadratic tweening. |
ADW_EASE_OUT_QUAD |
Quadratic tweening, inverse of |
ADW_EASE_IN_OUT_QUAD |
Quadratic tweening, combining |
ADW_EASE_IN_CUBIC |
Cubic tweening. |
ADW_EASE_OUT_CUBIC |
Cubic tweening, inverse of |
ADW_EASE_IN_OUT_CUBIC |
Cubic tweening, combining |
ADW_EASE_IN_QUART |
Quartic tweening. |
ADW_EASE_OUT_QUART |
Quartic tweening, inverse of |
ADW_EASE_IN_OUT_QUART |
Quartic tweening, combining |
ADW_EASE_IN_QUINT |
Quintic tweening. |
ADW_EASE_OUT_QUINT |
Quintic tweening, inverse of |
ADW_EASE_IN_OUT_QUINT |
Quintic tweening, combining |
ADW_EASE_IN_SINE |
Sine wave tweening. |
ADW_EASE_OUT_SINE |
Sine wave tweening, inverse of |
ADW_EASE_IN_OUT_SINE |
Sine wave tweening, combining |
ADW_EASE_IN_EXPO |
Exponential tweening. |
ADW_EASE_OUT_EXPO |
Exponential tweening, inverse of |
ADW_EASE_IN_OUT_EXPO |
Exponential tweening, combining |
ADW_EASE_IN_CIRC |
Circular tweening. |
ADW_EASE_OUT_CIRC |
Circular tweening, inverse of |
ADW_EASE_IN_OUT_CIRC |
Circular tweening, combining |
ADW_EASE_IN_ELASTIC |
Elastic tweening, with offshoot on start. |
ADW_EASE_OUT_ELASTIC |
Elastic tweening, with offshoot on end, inverse of
|
ADW_EASE_IN_OUT_ELASTIC |
Elastic tweening, with offshoot on both ends,
combining |
ADW_EASE_IN_BACK |
Overshooting cubic tweening, with backtracking on start. |
ADW_EASE_OUT_BACK |
Overshooting cubic tweening, with backtracking on end,
inverse of |
ADW_EASE_IN_OUT_BACK |
Overshooting cubic tweening, with backtracking on both
ends, combining |
ADW_EASE_IN_BOUNCE |
Exponentially decaying parabolic (bounce) tweening, on start. |
ADW_EASE_OUT_BOUNCE |
Exponentially decaying parabolic (bounce) tweening,
with bounce on end, inverse of |
ADW_EASE_IN_OUT_BOUNCE |
Exponentially decaying parabolic (bounce) tweening,
with bounce on both ends, combining |
ADW_EASE |
Cubic bezier tweening, with control points in (0.25, 0.1) and (0.25, 1.0). Increases in velocity towards the middle of the animation, slowing back down at the end. |
ADW_EASE_IN |
Cubic bezier tweening, with control points in (0.42, 0.0) and (1.0, 1.0). Starts off slowly, with the speed of the animation increasing until complete. |
ADW_EASE_OUT |
Cubic bezier tweening, with control points in (0.0, 0.0) and (0.58, 1.0). Starts quickly, slowing down the animation until complete. |
ADW_EASE_IN_OUT |
Cubic bezier tweening, with control points in (0.42, 0.0) and (0.58, 1.0). Starts off slowly, speeds up in the middle, and then slows down again. |