Enumeration
AdwWrapPolicy
Description [src]
Describes line wrapping behavior in a AdwWrapLayout or AdwWrapBox.
| Available since: | 1.7 |
Members
| Name | Description |
|---|---|
ADW_WRAP_MINIMUM |
Fit as many children into each line as possible, shrinking them down to their minimum size before wrapping to the next line. |
ADW_WRAP_NATURAL |
Wrap to the next line as soon as the previous line cannot fit any more children without shrinking them past their natural size. |