Enumeration
AdwJustifyMode
Description [src]
Describes line justify behaviors in a AdwWrapLayout or AdwWrapBox.
See AdwWrapLayout:justify and AdwWrapBox:justify.
| Available since: | 1.7 |
Members
| Name | Description |
|---|---|
ADW_JUSTIFY_NONE |
Don’t justify children within a line. |
ADW_JUSTIFY_FILL |
Stretch each child within the line, keeping consistent spacing, so that the line fills the entire length. |
ADW_JUSTIFY_SPREAD |
Increase spacing between children, moving the children so that the first and last child are aligned with the beginning and end of the line. If the line only contains a single widget, it will be stretched regardless. |